@@ -30,6 +30,9 @@
 #include <QMainWindow>
 #include <QTime>
 
+class MGameLog;
+typedef QSharedPointer<MGameLog> MSharedGameLog;
+
 /*! \brief Logging facility for Miniature.
  *
  *  This class allows other components to append messages to the game log via
@@ -37,7 +40,7 @@
  *  *how* the messages are reported.
  */
 class MGameLog
-: public QObject
+    : public QObject
 {
     Q_OBJECT
 
