@@ -24,14 +24,8 @@
 
 #include "position.h"
 
-#include <QGraphicsItem>
-#include <QGraphicsWidget>
-#include <QGraphicsSvgItem>
-#include <QGraphicsRectItem>
-#include <QGraphicsSceneMouseEvent>
-#include <QUrl>
-#include <QVector>
-#include <QPainter>
+#include <QtCore>
+#include <QtGui>
 
 namespace Miniature
 {
@@ -42,12 +36,12 @@ namespace Miniature
  * We use the QGraphicsObject so that we can use signals and slots.
  */
 class MGraphicsBoardItem
-: public QGraphicsWidget
+: public QGraphicsObject
 {
     Q_OBJECT
 
 public:
-    MGraphicsBoardItem(int size = 480, QGraphicsItem *parent = 0, Qt::WindowFlags flags = Qt::Widget);
+    MGraphicsBoardItem(bool rotated, int size = 480, QGraphicsItem *parent = 0);
     ~MGraphicsBoardItem();
 
     // TODO: rename to cellSize(), more qt-ish
@@ -59,6 +53,12 @@ public:
 
     void hidePieces();
 
+    //! A disabled board emits no signals.
+    void disable();
+
+    //! A board only emits signals when enabled.
+    void enable();
+
     /*!
      *  Adds a piece (which is also a graphics object) to the board item,
      *  connects propagated signals and also takes ownership.
@@ -75,18 +75,22 @@ public:
 Q_SIGNALS:
     void pieceClicked(MPiece *piece);
     void targetClicked(const QPoint &cell);
-    void rotatePieces180();
-    void rotatePieces0();
     void togglePieceRotations();
+    void pieceRotationRequested0();
+    void pieceRotationRequested180();
 
-public Q_SLOT:
-    void onMouseButtonPressed(QGraphicsSceneMouseEvent *event);
+public Q_SLOTS:
+    void onPieceClicked(MPiece *piece);
+    void rotatePieces0();
+    void rotatePieces180();
 
 protected:
     virtual void mousePressEvent(QGraphicsSceneMouseEvent *event);
 
 private:
+    bool m_active;
     const int m_board_size;
+    bool boardRotated;
 };
 
 };
